<template>
  <div class="app-container">
    <div class="filter-container">
      <el-input
        :disabled="disabled"
        v-model="listQuery.searchname"
        placeholder="输入数据组名称搜索"
        style="width: 200px;"
        class="filter-item"
        @change="handleFilter"
        clearable
        @keyup.enter.native="handleFilter"
      />
      <el-button class="filter-item" style="margin-left: 10px;" type="primary" icon="el-icon-search" @click="handleFilter">{{ $t('common.search') }}</el-button>
      <el-button class="filter-item" style="margin-left: 2px;" type="primary" icon="el-icon-edit" @click="handleAdd">{{ $t('common.add') }}</el-button>
    </div>

    <el-table stripe :data="list" border fit style="width: 80%">
      <el-table-column label="序号" type="index" align="center" width="60">
        <template slot-scope="scope">
          <span>{{ scope.$index + 1 + (listQuery.page - 1) * 10 }}</span>
        </template>
      </el-table-column>
      <el-table-column label="代码" align="center" width="100">
        <template slot-scope="scope">
          <span>{{ scope.row.groupcode }}</span>
        </template>
      </el-table-column>
      <el-table-column label="名称" align="center" width="200">
        <template slot-scope="scope">
          <span>{{ scope.row.groupname }}</span>
        </template>
      </el-table-column>
      <el-table-column label="备注" align="center">
        <template slot-scope="scope">
          <span>{{ scope.row.comment }}</span>
        </template>
      </el-table-column>
      <el-table-column label="操作" align="center" width="200">
        <template slot-scope="scope">
          <el-button size="mini" type="primary" @click="handleEdit(scope.$index, scope.row)">{{ $t('common.edit') }}</el-button>
          <el-button size="mini" type="danger" @click="handleDelete(scope.$index, scope.row)">{{ $t('common.delete') }}</el-button>
        </template>
      </el-table-column>
    </el-table>

    <el-dialog
      :close-on-click-modal="false"
      :destroy-on-close="true"
      :title="disabled ? '查看信息' : dialogState === 1 ? '填写信息' : '修改信息'"
      :visible.sync="dialogVisible"
      width="30%"
      :before-close="handleClose"
    >
      <el-form ref="dialogform" :model="form" :rules="rules" label-width="80px">
        <el-form-item prop="groupcode" label="代码">
          <el-input :disabled="disabled" v-model="form.groupcode"></el-input>
        </el-form-item>
        <el-form-item prop="groupname" label="名称">
          <el-input :disabled="disabled" v-model="form.groupname" value></el-input>
        </el-form-item>
        <el-form-item prop="comment" label="备注">
          <el-input :disabled="disabled" v-model="form.comment"></el-input>
        </el-form-item>
        <el-form-item align="center" label-width="0">
          <el-button type="primary" @click="onSubmit(form)">{{ dialogState === 1 ? $t('common.add') : $t('common.save') }}</el-button>
          <el-button :style="disabled ? 'display:none' : ''" @click="dialogVisible = false">{{ $t('common.cancel') }}</el-button>
        </el-form-item>
      </el-form>
    </el-dialog>

    <pagination v-show="total > 0" :total="total" :page.sync="listQuery.page" :limit.sync="listQuery.limit" @pagination="fetchList" />
  </div>
</template>

<script>
import { getGroupList, addConfigGroup, updateConfigGroup, deleteConfigGroupById, getConfigGroupById } from '@/api/configgroup';
import Pagination from '@/components/Pagination';

export default {
  components: { Pagination },
  data() {
    return {
      disabled: false,
      total: 0,
      list: [],
      listQuery: {
        searchname: '',
        page: 1,
        limit: 10
      },
      dialogState: 1, //1:add, 2:edit
      dialogVisible: false,
      form: {
        groupcode: '',
        groupname: '',
        comment: ''
      },
      rules: {
        groupcode: [{ required: true, message: '代码不能为空', trigvalueger: 'blur' }],
        groupname: [{ required: true, message: '名称不能为空', trigger: 'blur' }]
      }
    };
  },
  mounted() {
    this.fetchList();
  },
  methods: {
    handleView(id) {
      this.handleEdit(id);
      this.disabled = true;
    },
    async fetchList() {
      const res = await getGroupList(this.listQuery);
      if (res && res.result) {
        this.total = res.data.total;
        this.list = res.data.list;
      }
    },

    handleFilter() {
      this.listQuery.page = 1;
      this.fetchList();
    },
    handleAdd() {
      this.form = {
        groupcode: '',
        groupname: '',
        comment: ''
      };
      this.dialogState = 1;
      this.dialogVisible = true;
    },
    async handleEdit(index, row) {
      this.dialogState = 2;
      this.form = deepClone(row);

      const res = await getConfigGroupById(row.id);
      if (res && res.result) {
        this.dialogVisible = true;
      }
    },
    handleDelete(index, row) {
      console.log(index, row);
      const _this = this;
      this.$confirm(this.$t('message.delete_confirm'), this.$t('common.tip'), {
        confirmButtonText: this.$t('common.ok'),
        cancelButtonText: this.$t('common.cancel'),
        type: 'warning'
      })
        .then(() => {
          deleteConfigGroupById(row.id).then(res => {
            if (res.result) {
              this.$message(this.$t('message.delete_success'), 'success');
              this.fetchList();
            } else {
              this.$message(this.$t('message.delete_fail'), 'error');
            }
          });
        })
        .catch(error => {});
    },
    handleClose(done) {
      done();
    },
    onSubmit() {
      this.$refs.dialogform.validate(valid => {
        if (!valid) {
          this.$message('填写的信息有误，请确认', 'error');
          return;
        }

        if (this.dialogState === 1) {
          const data = Object.assign(this.form);
          addConfigGroup(data)
            .then(res => {
              if (!res.result) {
                this.$message(res.errorMsg || this.$t('message.add_fail'), 'error');
                return;
              }
              this.$message(this.$t('message.add_success'), 'success');
              this.fetchList();
              this.dialogVisible = false;
            })
            .catch(error => {});
        } else {
          updateConfigGroup(this.form)
            .then(res => {
              if (!res.result) {
                this.$message(res.errorMsg || this.$t('message.edit_fail'), 'error');
                return;
              }
              this.$message(this.$t('message.edit_success'), 'success');
              this.fetchList();
              this.dialogVisible = false;
            })
            .catch(error => {});
        }
      });
    }
  }
};
</script>
